@@ -16,16 +16,21 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.cloud.monitoring_dashboard_v1.services.dashboards_service import pagers
 from google.cloud.monitoring_dashboard_v1.types import dashboard
 from google.cloud.monitoring_dashboard_v1.types import dashboards_service
@@ -109,6 +114,42 @@ class DashboardsServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return DashboardsServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> DashboardsServiceTransport:
         """Returns the transport used by the client instance.
@@ -171,9 +212,9 @@ class DashboardsServiceAsyncClient:
 
     async def create_dashboard(
         self,
-        request: dashboards_service.CreateDashboardRequest = None,
+        request: Union[dashboards_service.CreateDashboardRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dashboard.Dashboard:
@@ -185,8 +226,32 @@ class DashboardsServiceAsyncClient:
         permissions, see `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
+
+        .. code-block::
+
+            from google.monitoring import dashboard_v1
+
+            def sample_create_dashboard():
+                # Create a client
+                client = dashboard_v1.DashboardsServiceClient()
+
+                # Initialize request argument(s)
+                dashboard = dashboard_v1.Dashboard()
+                dashboard.display_name = "display_name_value"
+
+                request = dashboard_v1.CreateDashboardRequest(
+                    parent="parent_value",
+                    dashboard=dashboard,
+                )
+
+                # Make the request
+                response = client.create_dashboard(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.monitoring_dashboard_v1.types.CreateDashboardRequest`):
+            request (Union[google.cloud.monitoring_dashboard_v1.types.CreateDashboardRequest, dict]):
                 The request object. The `CreateDashboard` request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -227,9 +292,9 @@ class DashboardsServiceAsyncClient:
 
     async def list_dashboards(
         self,
-        request: dashboards_service.ListDashboardsRequest = None,
+        request: Union[dashboards_service.ListDashboardsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDashboardsAsyncPager:
@@ -240,8 +305,29 @@ class DashboardsServiceAsyncClient:
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
+
+        .. code-block::
+
+            from google.monitoring import dashboard_v1
+
+            def sample_list_dashboards():
+                # Create a client
+                client = dashboard_v1.DashboardsServiceClient()
+
+                # Initialize request argument(s)
+                request = dashboard_v1.ListDashboardsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_dashboards(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.monitoring_dashboard_v1.types.ListDashboardsRequest`):
+            request (Union[google.cloud.monitoring_dashboard_v1.types.ListDashboardsRequest, dict]):
                 The request object. The `ListDashboards` request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -288,9 +374,9 @@ class DashboardsServiceAsyncClient:
 
     async def get_dashboard(
         self,
-        request: dashboards_service.GetDashboardRequest = None,
+        request: Union[dashboards_service.GetDashboardRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dashboard.Dashboard:
@@ -301,8 +387,28 @@ class DashboardsServiceAsyncClient:
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
+
+        .. code-block::
+
+            from google.monitoring import dashboard_v1
+
+            def sample_get_dashboard():
+                # Create a client
+                client = dashboard_v1.DashboardsServiceClient()
+
+                # Initialize request argument(s)
+                request = dashboard_v1.GetDashboardRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_dashboard(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.monitoring_dashboard_v1.types.GetDashboardRequest`):
+            request (Union[google.cloud.monitoring_dashboard_v1.types.GetDashboardRequest, dict]):
                 The request object. The `GetDashboard` request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -343,9 +449,9 @@ class DashboardsServiceAsyncClient:
 
     async def delete_dashboard(
         self,
-        request: dashboards_service.DeleteDashboardRequest = None,
+        request: Union[dashboards_service.DeleteDashboardRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -356,8 +462,25 @@ class DashboardsServiceAsyncClient:
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
+
+        .. code-block::
+
+            from google.monitoring import dashboard_v1
+
+            def sample_delete_dashboard():
+                # Create a client
+                client = dashboard_v1.DashboardsServiceClient()
+
+                # Initialize request argument(s)
+                request = dashboard_v1.DeleteDashboardRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_dashboard(request=request)
+
         Args:
-            request (:class:`google.cloud.monitoring_dashboard_v1.types.DeleteDashboardRequest`):
+            request (Union[google.cloud.monitoring_dashboard_v1.types.DeleteDashboardRequest, dict]):
                 The request object. The `DeleteDashboard` request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -389,9 +512,9 @@ class DashboardsServiceAsyncClient:
 
     async def update_dashboard(
         self,
-        request: dashboards_service.UpdateDashboardRequest = None,
+        request: Union[dashboards_service.UpdateDashboardRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dashboard.Dashboard:
@@ -402,8 +525,31 @@ class DashboardsServiceAsyncClient:
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
+
+        .. code-block::
+
+            from google.monitoring import dashboard_v1
+
+            def sample_update_dashboard():
+                # Create a client
+                client = dashboard_v1.DashboardsServiceClient()
+
+                # Initialize request argument(s)
+                dashboard = dashboard_v1.Dashboard()
+                dashboard.display_name = "display_name_value"
+
+                request = dashboard_v1.UpdateDashboardRequest(
+                    dashboard=dashboard,
+                )
+
+                # Make the request
+                response = client.update_dashboard(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.monitoring_dashboard_v1.types.UpdateDashboardRequest`):
+            request (Union[google.cloud.monitoring_dashboard_v1.types.UpdateDashboardRequest, dict]):
                 The request object. The `UpdateDashboard` request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
