@@ -14,22 +14,26 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.cloud.monitoring_dashboard_v1.services.dashboards_service import pagers
 from google.cloud.monitoring_dashboard_v1.types import dashboard
 from google.cloud.monitoring_dashboard_v1.types import dashboards_service
@@ -248,6 +252,73 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -298,50 +369,22 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, DashboardsServiceTransport):
             # transport is a DashboardsServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -353,6 +396,15 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -369,7 +421,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         self,
         request: Union[dashboards_service.CreateDashboardRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dashboard.Dashboard:
@@ -381,6 +433,31 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         permissions, see `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
+
+
+        .. code-block::
+
+            from google.monitoring import dashboard_v1
+
+            def sample_create_dashboard():
+                # Create a client
+                client = dashboard_v1.DashboardsServiceClient()
+
+                # Initialize request argument(s)
+                dashboard = dashboard_v1.Dashboard()
+                dashboard.display_name = "display_name_value"
+
+                request = dashboard_v1.CreateDashboardRequest(
+                    parent="parent_value",
+                    dashboard=dashboard,
+                )
+
+                # Make the request
+                response = client.create_dashboard(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.monitoring_dashboard_v1.types.CreateDashboardRequest, dict]):
                 The request object. The `CreateDashboard` request.
@@ -426,7 +503,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         self,
         request: Union[dashboards_service.ListDashboardsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDashboardsPager:
@@ -437,6 +514,28 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
+
+
+        .. code-block::
+
+            from google.monitoring import dashboard_v1
+
+            def sample_list_dashboards():
+                # Create a client
+                client = dashboard_v1.DashboardsServiceClient()
+
+                # Initialize request argument(s)
+                request = dashboard_v1.ListDashboardsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_dashboards(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.monitoring_dashboard_v1.types.ListDashboardsRequest, dict]):
                 The request object. The `ListDashboards` request.
@@ -488,7 +587,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         self,
         request: Union[dashboards_service.GetDashboardRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dashboard.Dashboard:
@@ -499,6 +598,27 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
+
+
+        .. code-block::
+
+            from google.monitoring import dashboard_v1
+
+            def sample_get_dashboard():
+                # Create a client
+                client = dashboard_v1.DashboardsServiceClient()
+
+                # Initialize request argument(s)
+                request = dashboard_v1.GetDashboardRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_dashboard(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.monitoring_dashboard_v1.types.GetDashboardRequest, dict]):
                 The request object. The `GetDashboard` request.
@@ -544,7 +664,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         self,
         request: Union[dashboards_service.DeleteDashboardRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -555,6 +675,24 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
+
+
+        .. code-block::
+
+            from google.monitoring import dashboard_v1
+
+            def sample_delete_dashboard():
+                # Create a client
+                client = dashboard_v1.DashboardsServiceClient()
+
+                # Initialize request argument(s)
+                request = dashboard_v1.DeleteDashboardRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_dashboard(request=request)
+
         Args:
             request (Union[google.cloud.monitoring_dashboard_v1.types.DeleteDashboardRequest, dict]):
                 The request object. The `DeleteDashboard` request.
@@ -591,7 +729,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         self,
         request: Union[dashboards_service.UpdateDashboardRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dashboard.Dashboard:
@@ -602,6 +740,30 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
+
+
+        .. code-block::
+
+            from google.monitoring import dashboard_v1
+
+            def sample_update_dashboard():
+                # Create a client
+                client = dashboard_v1.DashboardsServiceClient()
+
+                # Initialize request argument(s)
+                dashboard = dashboard_v1.Dashboard()
+                dashboard.display_name = "display_name_value"
+
+                request = dashboard_v1.UpdateDashboardRequest(
+                    dashboard=dashboard,
+                )
+
+                # Make the request
+                response = client.update_dashboard(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.monitoring_dashboard_v1.types.UpdateDashboardRequest, dict]):
                 The request object. The `UpdateDashboard` request.
