@@ -31,20 +31,37 @@ class Widget(proto.Message):
     r"""Widget contains a single dashboard component and
     configuration of how to present the component in the dashboard.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         title (str):
             Optional. The title of the widget.
         xy_chart (google.cloud.monitoring_dashboard_v1.types.XyChart):
             A chart of time series data.
+
+            This field is a member of `oneof`_ ``content``.
         scorecard (google.cloud.monitoring_dashboard_v1.types.Scorecard):
             A scorecard summarizing time series data.
+
+            This field is a member of `oneof`_ ``content``.
         text (google.cloud.monitoring_dashboard_v1.types.Text):
             A raw string or markdown displaying textual
             content.
+
+            This field is a member of `oneof`_ ``content``.
         blank (google.protobuf.empty_pb2.Empty):
             A blank space.
+
+            This field is a member of `oneof`_ ``content``.
         alert_chart (google.cloud.monitoring_dashboard_v1.types.AlertChart):
             A chart of alert policy data.
+
+            This field is a member of `oneof`_ ``content``.
     """
 
     title = proto.Field(proto.STRING, number=1,)
